### Challenge

Improve the prototype of our LLM-based assistant to suggest users how to run MLPerf inference benchmarks
using the MLCommons CM automation language: https://access.cknowledge.org/assistant .

Read [this documentation](https://github.com/mlcommons/ck/blob/master/docs/mlperf/inference/README.md) 
to run reference implementations of MLPerf inference benchmarks 
using the CM automation language and use them as a base for your developments.

Check [this ACM REP'23 keynote](https://doi.org/10.5281/zenodo.8105339) to learn more about our open-source project and long-term vision.


### Prizes

* *Get in touch with organizers for more info!*


### Organizers

* [cKnowledge.org](https://www.linkedin.com/company/cknowledge)
